# -*- coding: utf-8 -*-
"""
@author:XuMing(xuming624@qq.com)
@description: refer https://github.com/ThilinaRajapakse/simpletransformers
"""

from textgen.config.model_args import Seq2SeqArgs
from textgen.seq2seq.bart_seq2seq_model import BartSeq2SeqModel
from textgen.seq2seq.seq2seq_model import Seq2SeqModel
from textgen.seq2seq.conv_seq2seq_model import ConvSeq2SeqModel
